@@ -30,7 +30,7 @@ Client::Client(Daemon *parent, const QString &serviceName)
 
 Client::~Client()
 {
-    for (auto sensor : qAsConst(m_subscribedSensors)) {
+    for (auto sensor : std::as_const(m_subscribedSensors)) {
         sensor->unsubscribe();
     }
 }
@@ -103,3 +103,5 @@ void Client::sendMetaDataChanged(const KSysGuard::SensorInfoMap &sensors)
     msg.setArguments({QVariant::fromValue(sensors)});
     QDBusConnection::sessionBus().send(msg);
 }
+
+#include "moc_client.cpp"
